import requests, json
from zilonis.constantes import constantes

def getEstados(token):
    url = constantes.API+'/api/v1/cotizacion/estados'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json


def getMunicipios(token, idestado):
    url = constantes.API+'/api/v1/cotizacion/estado/'+str(idestado)+'/municipios'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json


def getColonias(token, idmunicipio):
    url = constantes.API+'/api/v1/cotizacion/municipio/'+str(idmunicipio)+'/colonias'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json


def getCodigosPostales(token, idcodigo):
    url = constantes.API+'/api/v1/cotizacion/codigopostal/'+str(idcodigo)+'/codigospostales'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json


import requests, json
from zilonis.constantes import constantes

def getLogin(user, pase):
    url = constantes.API+'/api/v1/usuario/login'
    headers = {'Content-Type': 'application/json'}
    args = {'username':user,'password':pase}
    response = requests.post(url, json=args, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    elif response.status_code == 404:
        response_json = {'Error':'Usuario no encontrado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json

def regUsuario(**data):
    url = constantes.API+'/api/v1/usuario/crear'
    headers = headers = {'Content-Type': 'application/json'}

    response = requests.post(url, json=data, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    elif response.status_code == 400:
        response_json = {'Error':'Usuario ya existe'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json

def insertaClaves(token, **data):
    url = constantes.API+'/api/v1/usuario/save/claveagente'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.post(url, json=data, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json


import requests, json
from zilonis.constantes import constantes

def getEdades(token):
    url = constantes.API+'/api/v1/cotizacion/edad'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json



import requests, json
from zilonis.constantes import constantes

def getMarcas(token):
    url = constantes.API+'/api/v1/cotizacion/marcas'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json


def getSubMarcas(token, idmarca):
    url = constantes.API+'/api/v1/cotizacion/marca/'+str(idmarca)+'/submarcas'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json

def getModelos(token, idsubmarca):
    url = constantes.API+'/api/v1/cotizacion/submarca/'+str(idsubmarca)+'/modelos'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json


def getDescripcion(token, idsubmarca, idmodelo):
    url = constantes.API+'/api/v1/cotizacion/submarca/'+str(idsubmarca)+'/modelo/'+str(idmodelo)+'/descripciones'
    headers = {'Accept':'application/json','Authorization':'Bearer '+token}

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        response_json = json.loads(response.text)
    elif response.status_code == 401:
        response_json = {'Error':'Acceso Denegado'}
    else:
        response_json = {'Error':'Servicio fuera linea'}

    return response_json


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri Jun 25 18:39:39 2021

@author: Alejandro Maldonado.
"""
#Archivo distribuible
from setuptools import setup


setup(
      name="zilonis",
      version="1.4",
      author="Alejandro Maldonado",
      author_email="alejandro.maldonado@gonet.us",
      description="Consumo Privado de API Cotizador",
      url="",
      scripts=[],
      packages=["zilonis",
                  "zilonis.login", 
                  "zilonis.constantes",
                  "zilonis.vehiculo",
                  "zilonis.ubicacion",
                  "zilonis.persona",
                  "zilonis.cotizador"]
)